@@ -60,7 +60,7 @@ public:
     /**
      * @brief Returns whether the event was removed
      */
-    bool deleted() const;
+    [[nodiscard]] bool deleted() const;
 
     /**
      * @brief Sets whether the event should use calendar's default reminders.
@@ -72,14 +72,14 @@ public:
     /**
      * @brief Returns whether the event should use calendar's default reminders.
      */
-    bool useDefaultReminders() const;
+    [[nodiscard]] bool useDefaultReminders() const;
 
     /**
      * @brief Returns ID used by Google to identify the event in calendar.
      *
      * This is not the same as UID.
      */
-    QString id() const;
+    [[nodiscard]] QString id() const;
 
     /**
      * @brief Sets event ID used by Google to identify the event in calendar.
@@ -89,7 +89,7 @@ public:
     /**
      * @brief Returns the hangout link for Google Meet.
      */
-    QString hangoutLink() const;
+    [[nodiscard]] QString hangoutLink() const;
 
     /**
      * @brief Sets the hangout link for Google Meet.
